@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -56,8 +57,6 @@ class NUDomainFIPAclTemplateEntry(NURESTObject):
     
     CONST_ACTION_REDIRECT = "REDIRECT"
     
-    CONST_DESTINATION_TYPE_NETWORK = "NETWORK"
-    
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
     CONST_NETWORK_TYPE_PUBLIC_NETWORK = "PUBLIC_NETWORK"
@@ -68,12 +67,8 @@ class NUDomainFIPAclTemplateEntry(NURESTObject):
     
     CONST_LOCATION_TYPE_ANY = "ANY"
     
-    CONST_SOURCE_TYPE_POLICYGROUP = "POLICYGROUP"
-    
     CONST_NETWORK_TYPE_ENDPOINT_DOMAIN = "ENDPOINT_DOMAIN"
     
-    CONST_SOURCE_TYPE_NETWORKPOLICYGROUP = "NETWORKPOLICYGROUP"
-    
     CONST_NETWORK_TYPE_ENTERPRISE_NETWORK = "ENTERPRISE_NETWORK"
     
     CONST_NETWORK_TYPE_ANY = "ANY"
@@ -84,30 +79,32 @@ class NUDomainFIPAclTemplateEntry(NURESTObject):
     
     CONST_NETWORK_TYPE_ZONE = "ZONE"
     
-    CONST_DESTINATION_TYPE_NETWORKPOLICYGROUP = "NETWORKPOLICYGROUP"
+    CONST_ASSOCIATED_TRAFFIC_TYPE_L4_SERVICE_GROUP = "L4_SERVICE_GROUP"
     
     CONST_NETWORK_TYPE_ENDPOINT_SUBNET = "ENDPOINT_SUBNET"
     
-    CONST_SOURCE_TYPE_NETWORK = "NETWORK"
-    
     CONST_LOCATION_TYPE_VPORTTAG = "VPORTTAG"
     
     CONST_LOCATION_TYPE_SUBNET = "SUBNET"
     
     CONST_POLICY_STATE_DRAFT = "DRAFT"
     
+    CONST_ASSOCIATED_TRAFFIC_TYPE_L4_SERVICE = "L4_SERVICE"
+    
+    CONST_WEB_FILTER_TYPE_WEB_DOMAIN_NAME = "WEB_DOMAIN_NAME"
+    
     CONST_LOCATION_TYPE_REDIRECTIONTARGET = "REDIRECTIONTARGET"
     
     CONST_POLICY_STATE_LIVE = "LIVE"
     
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
+    CONST_WEB_FILTER_TYPE_WEB_CATEGORY = "WEB_CATEGORY"
+    
     CONST_NETWORK_TYPE_INTERNET_POLICYGROUP = "INTERNET_POLICYGROUP"
     
     CONST_NETWORK_TYPE_ENDPOINT_ZONE = "ENDPOINT_ZONE"
     
-    CONST_DESTINATION_TYPE_POLICYGROUP = "POLICYGROUP"
-    
     
 
     def __init__(self, **kwargs):
@@ -134,14 +131,11 @@ class NUDomainFIPAclTemplateEntry(NURESTObject):
         self._dscp = None
         self._last_updated_by = None
         self._action = None
-        self._action_details = None
         self._address_override = None
+        self._web_filter_id = None
+        self._web_filter_type = None
         self._description = None
-        self._dest_pg_id = None
-        self._dest_pg_type = None
         self._destination_port = None
-        self._destination_type = None
-        self._destination_value = None
         self._network_id = None
         self._network_type = None
         self._mirror_destination_id = None
@@ -152,14 +146,13 @@ class NUDomainFIPAclTemplateEntry(NURESTObject):
         self._location_type = None
         self._policy_state = None
         self._domain_name = None
-        self._source_pg_id = None
-        self._source_pg_type = None
         self._source_port = None
-        self._source_type = None
-        self._source_value = None
         self._priority = None
         self._protocol = None
         self._associated_live_entity_id = None
+        self._associated_live_template_id = None
+        self._associated_traffic_type = None
+        self._associated_traffic_type_id = None
         self._stateful = None
         self._stats_id = None
         self._stats_logging_enabled = None
@@ -173,14 +166,11 @@ class NUDomainFIPAclTemplateEntry(NURESTObject):
         self.expose_attribute(local_name="dscp", remote_name="DSCP", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="action", remote_name="action", attribute_type=str, is_required=False, is_unique=False, choices=[u'DROP', u'FORWARD', u'REDIRECT'])
-        self.expose_attribute(local_name="action_details", remote_name="actionDetails", attribute_type=dict, is_required=False, is_unique=False)
         self.expose_attribute(local_name="address_override", remote_name="addressOverride", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="web_filter_id", remote_name="webFilterID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="web_filter_type", remote_name="webFilterType", attribute_type=str, is_required=False, is_unique=False, choices=[u'WEB_CATEGORY', u'WEB_DOMAIN_NAME'])
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="dest_pg_id", remote_name="destPgId", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="dest_pg_type", remote_name="destPgType", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="destination_port", remote_name="destinationPort", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="destination_type", remote_name="destinationType", attribute_type=str, is_required=False, is_unique=False, choices=[u'NETWORK', u'NETWORKPOLICYGROUP', u'POLICYGROUP'])
-        self.expose_attribute(local_name="destination_value", remote_name="destinationValue", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="network_id", remote_name="networkID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="network_type", remote_name="networkType", attribute_type=str, is_required=False, is_unique=False, choices=[u'ANY', u'ENDPOINT_DOMAIN', u'ENDPOINT_SUBNET', u'ENDPOINT_ZONE', u'ENTERPRISE_NETWORK', u'INTERNET_POLICYGROUP', u'NETWORK_MACRO_GROUP', u'POLICYGROUP', u'PUBLIC_NETWORK', u'SUBNET', u'ZONE'])
         self.expose_attribute(local_name="mirror_destination_id", remote_name="mirrorDestinationID", attribute_type=str, is_required=False, is_unique=False)
@@ -191,14 +181,13 @@ class NUDomainFIPAclTemplateEntry(NURESTObject):
         self.expose_attribute(local_name="location_type", remote_name="locationType", attribute_type=str, is_required=False, is_unique=False, choices=[u'ANY', u'POLICYGROUP', u'REDIRECTIONTARGET', u'SUBNET', u'VPORTTAG', u'ZONE'])
         self.expose_attribute(local_name="policy_state", remote_name="policyState", attribute_type=str, is_required=False, is_unique=False, choices=[u'DRAFT', u'LIVE'])
         self.expose_attribute(local_name="domain_name", remote_name="domainName", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="source_pg_id", remote_name="sourcePgId", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="source_pg_type", remote_name="sourcePgType", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="source_port", remote_name="sourcePort", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="source_type", remote_name="sourceType", attribute_type=str, is_required=False, is_unique=False, choices=[u'NETWORK', u'NETWORKPOLICYGROUP', u'POLICYGROUP'])
-        self.expose_attribute(local_name="source_value", remote_name="sourceValue", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="priority", remote_name="priority", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="protocol", remote_name="protocol", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_live_entity_id", remote_name="associatedLiveEntityID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_live_template_id", remote_name="associatedLiveTemplateID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_traffic_type", remote_name="associatedTrafficType", attribute_type=str, is_required=False, is_unique=False, choices=[u'L4_SERVICE', u'L4_SERVICE_GROUP'])
+        self.expose_attribute(local_name="associated_traffic_type_id", remote_name="associatedTrafficTypeID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="stateful", remote_name="stateful", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="stats_id", remote_name="statsID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="stats_logging_enabled", remote_name="statsLoggingEnabled", attribute_type=bool, is_required=False, is_unique=False)
@@ -404,33 +393,6 @@ class NUDomainFIPAclTemplateEntry(NURESTObject):
         self._action = value
 
     
-    @property
-    def action_details(self):
-        """ Get action_details value.
-
-            Notes:
-                Type of action to be performed when a ACL match criteria succeeds
-
-                
-                This attribute is named `actionDetails` in VSD API.
-                
-        """
-        return self._action_details
-
-    @action_details.setter
-    def action_details(self, value):
-        """ Set action_details value.
-
-            Notes:
-                Type of action to be performed when a ACL match criteria succeeds
-
-                
-                This attribute is named `actionDetails` in VSD API.
-                
-        """
-        self._action_details = value
-
-    
     @property
     def address_override(self):
         """ Get address_override value.
@@ -458,6 +420,60 @@ class NUDomainFIPAclTemplateEntry(NURESTObject):
         self._address_override = value
 
     
+    @property
+    def web_filter_id(self):
+        """ Get web_filter_id value.
+
+            Notes:
+                ID of web filter category or web domain name entity used
+
+                
+                This attribute is named `webFilterID` in VSD API.
+                
+        """
+        return self._web_filter_id
+
+    @web_filter_id.setter
+    def web_filter_id(self, value):
+        """ Set web_filter_id value.
+
+            Notes:
+                ID of web filter category or web domain name entity used
+
+                
+                This attribute is named `webFilterID` in VSD API.
+                
+        """
+        self._web_filter_id = value
+
+    
+    @property
+    def web_filter_type(self):
+        """ Get web_filter_type value.
+
+            Notes:
+                Indicates type of web filter being set
+
+                
+                This attribute is named `webFilterType` in VSD API.
+                
+        """
+        return self._web_filter_type
+
+    @web_filter_type.setter
+    def web_filter_type(self, value):
+        """ Set web_filter_type value.
+
+            Notes:
+                Indicates type of web filter being set
+
+                
+                This attribute is named `webFilterType` in VSD API.
+                
+        """
+        self._web_filter_type = value
+
+    
     @property
     def description(self):
         """ Get description value.
@@ -481,60 +497,6 @@ class NUDomainFIPAclTemplateEntry(NURESTObject):
         self._description = value
 
     
-    @property
-    def dest_pg_id(self):
-        """ Get dest_pg_id value.
-
-            Notes:
-                In case of PG this will be its EVPNBGPCommunity String, incase of network it will be network cidr
-
-                
-                This attribute is named `destPgId` in VSD API.
-                
-        """
-        return self._dest_pg_id
-
-    @dest_pg_id.setter
-    def dest_pg_id(self, value):
-        """ Set dest_pg_id value.
-
-            Notes:
-                In case of PG this will be its EVPNBGPCommunity String, incase of network it will be network cidr
-
-                
-                This attribute is named `destPgId` in VSD API.
-                
-        """
-        self._dest_pg_id = value
-
-    
-    @property
-    def dest_pg_type(self):
-        """ Get dest_pg_type value.
-
-            Notes:
-                In case of PG this will be its EVPNBGPCommunity String, incase of network it will be network cidr
-
-                
-                This attribute is named `destPgType` in VSD API.
-                
-        """
-        return self._dest_pg_type
-
-    @dest_pg_type.setter
-    def dest_pg_type(self, value):
-        """ Set dest_pg_type value.
-
-            Notes:
-                In case of PG this will be its EVPNBGPCommunity String, incase of network it will be network cidr
-
-                
-                This attribute is named `destPgType` in VSD API.
-                
-        """
-        self._dest_pg_type = value
-
-    
     @property
     def destination_port(self):
         """ Get destination_port value.
@@ -562,60 +524,6 @@ class NUDomainFIPAclTemplateEntry(NURESTObject):
         self._destination_port = value
 
     
-    @property
-    def destination_type(self):
-        """ Get destination_type value.
-
-            Notes:
-                Network Type - either PolicyGroup or Network
-
-                
-                This attribute is named `destinationType` in VSD API.
-                
-        """
-        return self._destination_type
-
-    @destination_type.setter
-    def destination_type(self, value):
-        """ Set destination_type value.
-
-            Notes:
-                Network Type - either PolicyGroup or Network
-
-                
-                This attribute is named `destinationType` in VSD API.
-                
-        """
-        self._destination_type = value
-
-    
-    @property
-    def destination_value(self):
-        """ Get destination_value value.
-
-            Notes:
-                In case of PG this will be its EVPNBGPCommunity String, incase of network it will be network cidr
-
-                
-                This attribute is named `destinationValue` in VSD API.
-                
-        """
-        return self._destination_value
-
-    @destination_value.setter
-    def destination_value(self, value):
-        """ Set destination_value value.
-
-            Notes:
-                In case of PG this will be its EVPNBGPCommunity String, incase of network it will be network cidr
-
-                
-                This attribute is named `destinationValue` in VSD API.
-                
-        """
-        self._destination_value = value
-
-    
     @property
     def network_id(self):
         """ Get network_id value.
@@ -886,60 +794,6 @@ class NUDomainFIPAclTemplateEntry(NURESTObject):
         self._domain_name = value
 
     
-    @property
-    def source_pg_id(self):
-        """ Get source_pg_id value.
-
-            Notes:
-                In case of PG this will be its EVPNBGPCommunity String, incase of network it will be network cidr
-
-                
-                This attribute is named `sourcePgId` in VSD API.
-                
-        """
-        return self._source_pg_id
-
-    @source_pg_id.setter
-    def source_pg_id(self, value):
-        """ Set source_pg_id value.
-
-            Notes:
-                In case of PG this will be its EVPNBGPCommunity String, incase of network it will be network cidr
-
-                
-                This attribute is named `sourcePgId` in VSD API.
-                
-        """
-        self._source_pg_id = value
-
-    
-    @property
-    def source_pg_type(self):
-        """ Get source_pg_type value.
-
-            Notes:
-                In case of PG this will be its EVPNBGPCommunity String, incase of network it will be network cidr
-
-                
-                This attribute is named `sourcePgType` in VSD API.
-                
-        """
-        return self._source_pg_type
-
-    @source_pg_type.setter
-    def source_pg_type(self, value):
-        """ Set source_pg_type value.
-
-            Notes:
-                In case of PG this will be its EVPNBGPCommunity String, incase of network it will be network cidr
-
-                
-                This attribute is named `sourcePgType` in VSD API.
-                
-        """
-        self._source_pg_type = value
-
-    
     @property
     def source_port(self):
         """ Get source_port value.
@@ -967,60 +821,6 @@ class NUDomainFIPAclTemplateEntry(NURESTObject):
         self._source_port = value
 
     
-    @property
-    def source_type(self):
-        """ Get source_type value.
-
-            Notes:
-                Location Type - either PolicyGroup or Network
-
-                
-                This attribute is named `sourceType` in VSD API.
-                
-        """
-        return self._source_type
-
-    @source_type.setter
-    def source_type(self, value):
-        """ Set source_type value.
-
-            Notes:
-                Location Type - either PolicyGroup or Network
-
-                
-                This attribute is named `sourceType` in VSD API.
-                
-        """
-        self._source_type = value
-
-    
-    @property
-    def source_value(self):
-        """ Get source_value value.
-
-            Notes:
-                In case of PG this will be its EVPNBGPCommunity String, incase of network it will be network cidr
-
-                
-                This attribute is named `sourceValue` in VSD API.
-                
-        """
-        return self._source_value
-
-    @source_value.setter
-    def source_value(self, value):
-        """ Set source_value value.
-
-            Notes:
-                In case of PG this will be its EVPNBGPCommunity String, incase of network it will be network cidr
-
-                
-                This attribute is named `sourceValue` in VSD API.
-                
-        """
-        self._source_value = value
-
-    
     @property
     def priority(self):
         """ Get priority value.
@@ -1094,6 +894,87 @@ class NUDomainFIPAclTemplateEntry(NURESTObject):
         self._associated_live_entity_id = value
 
     
+    @property
+    def associated_live_template_id(self):
+        """ Get associated_live_template_id value.
+
+            Notes:
+                In the draft mode, the ACL entity refers to this live entity parent. In non-drafted mode, this is null
+
+                
+                This attribute is named `associatedLiveTemplateID` in VSD API.
+                
+        """
+        return self._associated_live_template_id
+
+    @associated_live_template_id.setter
+    def associated_live_template_id(self, value):
+        """ Set associated_live_template_id value.
+
+            Notes:
+                In the draft mode, the ACL entity refers to this live entity parent. In non-drafted mode, this is null
+
+                
+                This attribute is named `associatedLiveTemplateID` in VSD API.
+                
+        """
+        self._associated_live_template_id = value
+
+    
+    @property
+    def associated_traffic_type(self):
+        """ Get associated_traffic_type value.
+
+            Notes:
+                The associated Traffic type. L4 Service / L4 Service Group
+
+                
+                This attribute is named `associatedTrafficType` in VSD API.
+                
+        """
+        return self._associated_traffic_type
+
+    @associated_traffic_type.setter
+    def associated_traffic_type(self, value):
+        """ Set associated_traffic_type value.
+
+            Notes:
+                The associated Traffic type. L4 Service / L4 Service Group
+
+                
+                This attribute is named `associatedTrafficType` in VSD API.
+                
+        """
+        self._associated_traffic_type = value
+
+    
+    @property
+    def associated_traffic_type_id(self):
+        """ Get associated_traffic_type_id value.
+
+            Notes:
+                The associated Traffic Type ID
+
+                
+                This attribute is named `associatedTrafficTypeID` in VSD API.
+                
+        """
+        return self._associated_traffic_type_id
+
+    @associated_traffic_type_id.setter
+    def associated_traffic_type_id(self, value):
+        """ Set associated_traffic_type_id value.
+
+            Notes:
+                The associated Traffic Type ID
+
+                
+                This attribute is named `associatedTrafficTypeID` in VSD API.
+                
+        """
+        self._associated_traffic_type_id = value
+
+    
     @property
     def stateful(self):
         """ Get stateful value.
