@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -54,7 +55,7 @@ class NUIngressACLTemplate(NURESTObject):
     """ Represents a IngressACLTemplate in the VSD
 
         Notes:
-            Defines the template for an Ingress ACL.
+            An ingress security policy is a set of rules defining how network traffic is treated within a domain. Ingress Security Policies control traffic flowing into the network.
     """
 
     __rest_name__ = "ingressacltemplate"
@@ -65,6 +66,10 @@ class NUIngressACLTemplate(NURESTObject):
     
     CONST_POLICY_STATE_DRAFT = "DRAFT"
     
+    CONST_PRIORITY_TYPE_MIDDLE_FIREWALL = "MIDDLE_FIREWALL"
+    
+    CONST_PRIORITY_TYPE_TOP_FIREWALL = "TOP_FIREWALL"
+    
     CONST_POLICY_STATE_LIVE = "LIVE"
     
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
@@ -73,6 +78,8 @@ class NUIngressACLTemplate(NURESTObject):
     
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
+    CONST_PRIORITY_TYPE_BOTTOM_FIREWALL = "BOTTOM_FIREWALL"
+    
     CONST_PRIORITY_TYPE_TOP = "TOP"
     
     CONST_PRIORITY_TYPE_BOTTOM = "BOTTOM"
@@ -103,13 +110,12 @@ class NUIngressACLTemplate(NURESTObject):
         self._default_allow_non_ip = None
         self._description = None
         self._allow_address_spoof = None
-        self._allow_l2_address_spoof = None
         self._entity_scope = None
         self._policy_state = None
         self._priority = None
         self._priority_type = None
-        self._assoc_acl_template_id = None
         self._associated_live_entity_id = None
+        self._associated_virtual_firewall_policy_id = None
         self._auto_generate_priority = None
         self._external_id = None
         
@@ -120,13 +126,12 @@ class NUIngressACLTemplate(NURESTObject):
         self.expose_attribute(local_name="default_allow_non_ip", remote_name="defaultAllowNonIP", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allow_address_spoof", remote_name="allowAddressSpoof", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="allow_l2_address_spoof", remote_name="allowL2AddressSpoof", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="policy_state", remote_name="policyState", attribute_type=str, is_required=False, is_unique=False, choices=[u'DRAFT', u'LIVE'])
         self.expose_attribute(local_name="priority", remote_name="priority", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="priority_type", remote_name="priorityType", attribute_type=str, is_required=False, is_unique=False, choices=[u'BOTTOM', u'NONE', u'TOP'])
-        self.expose_attribute(local_name="assoc_acl_template_id", remote_name="assocAclTemplateId", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="priority_type", remote_name="priorityType", attribute_type=str, is_required=False, is_unique=False, choices=[u'BOTTOM', u'BOTTOM_FIREWALL', u'MIDDLE_FIREWALL', u'NONE', u'TOP', u'TOP_FIREWALL'])
         self.expose_attribute(local_name="associated_live_entity_id", remote_name="associatedLiveEntityID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_virtual_firewall_policy_id", remote_name="associatedVirtualFirewallPolicyID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="auto_generate_priority", remote_name="autoGeneratePriority", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
@@ -336,33 +341,6 @@ class NUIngressACLTemplate(NURESTObject):
         self._allow_address_spoof = value
 
     
-    @property
-    def allow_l2_address_spoof(self):
-        """ Get allow_l2_address_spoof value.
-
-            Notes:
-                If enabled, it will disable the default anti-spoof ACL for this domain that essentially prevents any VM to send packets that do not originate from that particular VM
-
-                
-                This attribute is named `allowL2AddressSpoof` in VSD API.
-                
-        """
-        return self._allow_l2_address_spoof
-
-    @allow_l2_address_spoof.setter
-    def allow_l2_address_spoof(self, value):
-        """ Set allow_l2_address_spoof value.
-
-            Notes:
-                If enabled, it will disable the default anti-spoof ACL for this domain that essentially prevents any VM to send packets that do not originate from that particular VM
-
-                
-                This attribute is named `allowL2AddressSpoof` in VSD API.
-                
-        """
-        self._allow_l2_address_spoof = value
-
-    
     @property
     def entity_scope(self):
         """ Get entity_scope value.
@@ -445,7 +423,7 @@ class NUIngressACLTemplate(NURESTObject):
         """ Get priority_type value.
 
             Notes:
-                None
+                Possible values: TOP, BOTTOM, TOP_FIREWALL, BOTTOM_FIREWALL, MIDDLE_FIREWALL or NONE. TOP and BOTTOM ACL policies can only be defined and managed on the template level, NONE can be used on both the template and instantiated level. TOP_FIREWALL, BOTTOM_FIREWALL, MIDDLE_FIREWALL are used to represent acls dirived from Virtual Firewall Policies. These allow for careful control of ACL priority handling.
 
                 
                 This attribute is named `priorityType` in VSD API.
@@ -458,7 +436,7 @@ class NUIngressACLTemplate(NURESTObject):
         """ Set priority_type value.
 
             Notes:
-                None
+                Possible values: TOP, BOTTOM, TOP_FIREWALL, BOTTOM_FIREWALL, MIDDLE_FIREWALL or NONE. TOP and BOTTOM ACL policies can only be defined and managed on the template level, NONE can be used on both the template and instantiated level. TOP_FIREWALL, BOTTOM_FIREWALL, MIDDLE_FIREWALL are used to represent acls dirived from Virtual Firewall Policies. These allow for careful control of ACL priority handling.
 
                 
                 This attribute is named `priorityType` in VSD API.
@@ -467,33 +445,6 @@ class NUIngressACLTemplate(NURESTObject):
         self._priority_type = value
 
     
-    @property
-    def assoc_acl_template_id(self):
-        """ Get assoc_acl_template_id value.
-
-            Notes:
-                ID of the ACL template associated with this ACL template
-
-                
-                This attribute is named `assocAclTemplateId` in VSD API.
-                
-        """
-        return self._assoc_acl_template_id
-
-    @assoc_acl_template_id.setter
-    def assoc_acl_template_id(self, value):
-        """ Set assoc_acl_template_id value.
-
-            Notes:
-                ID of the ACL template associated with this ACL template
-
-                
-                This attribute is named `assocAclTemplateId` in VSD API.
-                
-        """
-        self._assoc_acl_template_id = value
-
-    
     @property
     def associated_live_entity_id(self):
         """ Get associated_live_entity_id value.
@@ -521,12 +472,39 @@ class NUIngressACLTemplate(NURESTObject):
         self._associated_live_entity_id = value
 
     
+    @property
+    def associated_virtual_firewall_policy_id(self):
+        """ Get associated_virtual_firewall_policy_id value.
+
+            Notes:
+                The ID of the Virtual Firewall Policy, if this was created as part of the Virtual Firewall Policy creation
+
+                
+                This attribute is named `associatedVirtualFirewallPolicyID` in VSD API.
+                
+        """
+        return self._associated_virtual_firewall_policy_id
+
+    @associated_virtual_firewall_policy_id.setter
+    def associated_virtual_firewall_policy_id(self, value):
+        """ Set associated_virtual_firewall_policy_id value.
+
+            Notes:
+                The ID of the Virtual Firewall Policy, if this was created as part of the Virtual Firewall Policy creation
+
+                
+                This attribute is named `associatedVirtualFirewallPolicyID` in VSD API.
+                
+        """
+        self._associated_virtual_firewall_policy_id = value
+
+    
     @property
     def auto_generate_priority(self):
         """ Get auto_generate_priority value.
 
             Notes:
-                This option affects how ACL entry priorities are generated when not specified. If "false", the priority is generated by incrementing the current highest priority by 100. If "true", a random priority will be generated, which is advised when creating many entries concurrently without specifying the priority. This will cause the ACL entry to be randomly placed in the existing list of ACL entries. Therefore it is advised to only enable this when allow rules are being created.
+                This option affects how ACL entry priorities are generated when not specified. If 'false', the priority is generated by incrementing the current highest priority by 100. If 'true', a random priority will be generated, which is advised when creating many entries concurrently without specifying the priority. This will cause the ACL entry to be randomly placed in the existing list of ACL entries. Therefore it is advised to only enable this when allow rules are being created.
 
                 
                 This attribute is named `autoGeneratePriority` in VSD API.
@@ -539,7 +517,7 @@ class NUIngressACLTemplate(NURESTObject):
         """ Set auto_generate_priority value.
 
             Notes:
-                This option affects how ACL entry priorities are generated when not specified. If "false", the priority is generated by incrementing the current highest priority by 100. If "true", a random priority will be generated, which is advised when creating many entries concurrently without specifying the priority. This will cause the ACL entry to be randomly placed in the existing list of ACL entries. Therefore it is advised to only enable this when allow rules are being created.
+                This option affects how ACL entry priorities are generated when not specified. If 'false', the priority is generated by incrementing the current highest priority by 100. If 'true', a random priority will be generated, which is advised when creating many entries concurrently without specifying the priority. This will cause the ACL entry to be randomly placed in the existing list of ACL entries. Therefore it is advised to only enable this when allow rules are being created.
 
                 
                 This attribute is named `autoGeneratePriority` in VSD API.
