@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -85,12 +86,14 @@ class NULicense(NURESTObject):
         self._major_release = None
         self._last_updated_by = None
         self._additional_supported_versions = None
+        self._request_id = None
         self._phone = None
         self._license = None
         self._license_encryption = None
         self._license_entities = None
         self._license_id = None
         self._license_type = None
+        self._licensed_feature = None
         self._minor_release = None
         self._zip = None
         self._city = None
@@ -98,6 +101,8 @@ class NULicense(NURESTObject):
         self._allowed_avrss_count = None
         self._allowed_cpes_count = None
         self._allowed_nics_count = None
+        self._allowed_vdfgs_count = None
+        self._allowed_vdfs_count = None
         self._allowed_vms_count = None
         self._allowed_vrsgs_count = None
         self._allowed_vrss_count = None
@@ -117,16 +122,19 @@ class NULicense(NURESTObject):
         self._expiration_date = None
         self._expiry_timestamp = None
         self._external_id = None
+        self._system = None
         
         self.expose_attribute(local_name="major_release", remote_name="majorRelease", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="additional_supported_versions", remote_name="additionalSupportedVersions", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="request_id", remote_name="requestID", attribute_type=str, is_required=False, is_unique=True)
         self.expose_attribute(local_name="phone", remote_name="phone", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="license", remote_name="license", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="license_encryption", remote_name="licenseEncryption", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENCRYPTION_DISABLED', u'ENCRYPTION_ENABLED'])
         self.expose_attribute(local_name="license_entities", remote_name="licenseEntities", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="license_id", remote_name="licenseID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="license_type", remote_name="licenseType", attribute_type=str, is_required=False, is_unique=False, choices=[u'CLUSTERED', u'STANDARD'])
+        self.expose_attribute(local_name="licensed_feature", remote_name="licensedFeature", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="minor_release", remote_name="minorRelease", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="zip", remote_name="zip", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="city", remote_name="city", attribute_type=str, is_required=False, is_unique=False)
@@ -134,6 +142,8 @@ class NULicense(NURESTObject):
         self.expose_attribute(local_name="allowed_avrss_count", remote_name="allowedAVRSsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allowed_cpes_count", remote_name="allowedCPEsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allowed_nics_count", remote_name="allowedNICsCount", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="allowed_vdfgs_count", remote_name="allowedVDFGsCount", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="allowed_vdfs_count", remote_name="allowedVDFsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allowed_vms_count", remote_name="allowedVMsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allowed_vrsgs_count", remote_name="allowedVRSGsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allowed_vrss_count", remote_name="allowedVRSsCount", attribute_type=int, is_required=False, is_unique=False)
@@ -153,6 +163,7 @@ class NULicense(NURESTObject):
         self.expose_attribute(local_name="expiration_date", remote_name="expirationDate", attribute_type=float, is_required=False, is_unique=False)
         self.expose_attribute(local_name="expiry_timestamp", remote_name="expiryTimestamp", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
+        self.expose_attribute(local_name="system", remote_name="system", attribute_type=str, is_required=False, is_unique=False)
         
 
         # Fetchers
@@ -252,6 +263,33 @@ class NULicense(NURESTObject):
         self._additional_supported_versions = value
 
     
+    @property
+    def request_id(self):
+        """ Get request_id value.
+
+            Notes:
+                Unique number generated by the License Management system used to identify each license.
+
+                
+                This attribute is named `requestID` in VSD API.
+                
+        """
+        return self._request_id
+
+    @request_id.setter
+    def request_id(self, value):
+        """ Set request_id value.
+
+            Notes:
+                Unique number generated by the License Management system used to identify each license.
+
+                
+                This attribute is named `requestID` in VSD API.
+                
+        """
+        self._request_id = value
+
+    
     @property
     def phone(self):
         """ Get phone value.
@@ -406,6 +444,33 @@ class NULicense(NURESTObject):
         self._license_type = value
 
     
+    @property
+    def licensed_feature(self):
+        """ Get licensed_feature value.
+
+            Notes:
+                Indicates the feature supported by the license. Possible value is "vss".
+
+                
+                This attribute is named `licensedFeature` in VSD API.
+                
+        """
+        return self._licensed_feature
+
+    @licensed_feature.setter
+    def licensed_feature(self, value):
+        """ Set licensed_feature value.
+
+            Notes:
+                Indicates the feature supported by the license. Possible value is "vss".
+
+                
+                This attribute is named `licensedFeature` in VSD API.
+                
+        """
+        self._licensed_feature = value
+
+    
     @property
     def minor_release(self):
         """ Get minor_release value.
@@ -587,6 +652,60 @@ class NULicense(NURESTObject):
         self._allowed_nics_count = value
 
     
+    @property
+    def allowed_vdfgs_count(self):
+        """ Get allowed_vdfgs_count value.
+
+            Notes:
+                Maximum number of VDFGs enabled with this license. A value of -1 indicates an unlimited number of VDFGs.
+
+                
+                This attribute is named `allowedVDFGsCount` in VSD API.
+                
+        """
+        return self._allowed_vdfgs_count
+
+    @allowed_vdfgs_count.setter
+    def allowed_vdfgs_count(self, value):
+        """ Set allowed_vdfgs_count value.
+
+            Notes:
+                Maximum number of VDFGs enabled with this license. A value of -1 indicates an unlimited number of VDFGs.
+
+                
+                This attribute is named `allowedVDFGsCount` in VSD API.
+                
+        """
+        self._allowed_vdfgs_count = value
+
+    
+    @property
+    def allowed_vdfs_count(self):
+        """ Get allowed_vdfs_count value.
+
+            Notes:
+                Maximum number of VDFs enabled with this license. A value of -1 indicates an unlimited number of VDFs
+
+                
+                This attribute is named `allowedVDFsCount` in VSD API.
+                
+        """
+        return self._allowed_vdfs_count
+
+    @allowed_vdfs_count.setter
+    def allowed_vdfs_count(self, value):
+        """ Set allowed_vdfs_count value.
+
+            Notes:
+                Maximum number of VDFs enabled with this license. A value of -1 indicates an unlimited number of VDFs
+
+                
+                This attribute is named `allowedVDFsCount` in VSD API.
+                
+        """
+        self._allowed_vdfs_count = value
+
+    
     @property
     def allowed_vms_count(self):
         """ Get allowed_vms_count value.
@@ -1076,5 +1195,28 @@ class NULicense(NURESTObject):
         self._external_id = value
 
     
+    @property
+    def system(self):
+        """ Get system value.
+
+            Notes:
+                System name information provided by the License Management System.
+
+                
+        """
+        return self._system
+
+    @system.setter
+    def system(self, value):
+        """ Set system value.
+
+            Notes:
+                System name information provided by the License Management System.
+
+                
+        """
+        self._system = value
+
+    
 
     
\ No newline at end of file
