@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,10 @@
 
 
 
+
+from .fetchers import NUPermissionsFetcher
+
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -36,6 +40,9 @@ from .fetchers import NUVLANsFetcher
 from .fetchers import NUGlobalMetadatasFetcher
 
 
+from .fetchers import NUEnterprisePermissionsFetcher
+
+
 from .fetchers import NUNSPortsFetcher
 
 from bambou import NURESTObject
@@ -54,11 +61,9 @@ class NURedundantPort(NURESTObject):
     
     ## Constants
     
-    CONST_PORT_TYPE_NETWORK = "NETWORK"
-    
     CONST_PERMITTED_ACTION_USE = "USE"
     
-    CONST_SPEED_BASETX100 = "BASETX100"
+    CONST_SPEED_BASET10 = "BASET10"
     
     CONST_PERMITTED_ACTION_READ = "READ"
     
@@ -76,7 +81,7 @@ class NURedundantPort(NURESTObject):
     
     CONST_SPEED_BASET1000 = "BASET1000"
     
-    CONST_SPEED_BASE10 = "BASE10"
+    CONST_SPEED_BASEX10G = "BASEX10G"
     
     CONST_STATUS_MISMATCH = "MISMATCH"
     
@@ -90,7 +95,7 @@ class NURedundantPort(NURESTObject):
     
     CONST_SPEED_AUTONEGOTIATE = "AUTONEGOTIATE"
     
-    CONST_SPEED_BASEX10G = "BASEX10G"
+    CONST_SPEED_BASETX100 = "BASETX100"
     
     
 
@@ -131,7 +136,7 @@ class NURedundantPort(NURESTObject):
         self._status = None
         self._external_id = None
         
-        self.expose_attribute(local_name="vlan_range", remote_name="VLANRange", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="vlan_range", remote_name="VLANRange", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="mtu", remote_name="MTU", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
@@ -142,8 +147,8 @@ class NURedundantPort(NURESTObject):
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="port_peer1_id", remote_name="portPeer1ID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="port_peer2_id", remote_name="portPeer2ID", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="port_type", remote_name="portType", attribute_type=str, is_required=True, is_unique=False, choices=[u'ACCESS', u'NETWORK'])
-        self.expose_attribute(local_name="speed", remote_name="speed", attribute_type=str, is_required=False, is_unique=False, choices=[u'AUTONEGOTIATE', u'BASE10', u'BASET1000', u'BASETX100', u'BASEX10G'])
+        self.expose_attribute(local_name="port_type", remote_name="portType", attribute_type=str, is_required=True, is_unique=False, choices=[u'ACCESS'])
+        self.expose_attribute(local_name="speed", remote_name="speed", attribute_type=str, is_required=False, is_unique=False, choices=[u'AUTONEGOTIATE', u'BASET10', u'BASET1000', u'BASETX100', u'BASEX10G'])
         self.expose_attribute(local_name="use_untagged_heartbeat_vlan", remote_name="useUntaggedHeartbeatVlan", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="use_user_mnemonic", remote_name="useUserMnemonic", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="user_mnemonic", remote_name="userMnemonic", attribute_type=str, is_required=False, is_unique=False)
@@ -155,6 +160,9 @@ class NURedundantPort(NURESTObject):
         # Fetchers
         
         
+        self.permissions = NUPermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.metadatas = NUMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -164,6 +172,9 @@ class NURedundantPort(NURESTObject):
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.enterprise_permissions = NUEnterprisePermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.ns_ports = NUNSPortsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
 
@@ -230,7 +241,7 @@ class NURedundantPort(NURESTObject):
         """ Get name value.
 
             Notes:
-                Name of the Port
+                Name of the Redundant Port
 
                 
         """
@@ -241,7 +252,7 @@ class NURedundantPort(NURESTObject):
         """ Set name value.
 
             Notes:
-                Name of the Port
+                Name of the Redundant Port
 
                 
         """
@@ -280,7 +291,7 @@ class NURedundantPort(NURESTObject):
         """ Get permitted_action value.
 
             Notes:
-                The permitted  action to USE/EXTEND  this Gateway.
+                The permitted action to USE/EXTEND this Redundant Port.
 
                 
                 This attribute is named `permittedAction` in VSD API.
@@ -293,7 +304,7 @@ class NURedundantPort(NURESTObject):
         """ Set permitted_action value.
 
             Notes:
-                The permitted  action to USE/EXTEND  this Gateway.
+                The permitted action to USE/EXTEND this Redundant Port.
 
                 
                 This attribute is named `permittedAction` in VSD API.
@@ -307,7 +318,7 @@ class NURedundantPort(NURESTObject):
         """ Get description value.
 
             Notes:
-                A description of the Port
+                A description of the Redundant Port instance.
 
                 
         """
@@ -318,7 +329,7 @@ class NURedundantPort(NURESTObject):
         """ Set description value.
 
             Notes:
-                A description of the Port
+                A description of the Redundant Port instance.
 
                 
         """
@@ -330,7 +341,7 @@ class NURedundantPort(NURESTObject):
         """ Get physical_name value.
 
             Notes:
-                Identifier of the Port
+                Identifier of the Redundant Port.  The name should be corresponding to the Physical Name of the ports belonging to this redundant instance.
 
                 
                 This attribute is named `physicalName` in VSD API.
@@ -343,7 +354,7 @@ class NURedundantPort(NURESTObject):
         """ Set physical_name value.
 
             Notes:
-                Identifier of the Port
+                Identifier of the Redundant Port.  The name should be corresponding to the Physical Name of the ports belonging to this redundant instance.
 
                 
                 This attribute is named `physicalName` in VSD API.
@@ -357,7 +368,7 @@ class NURedundantPort(NURESTObject):
         """ Get infrastructure_profile_id value.
 
             Notes:
-                The ID of the infrastructure profile this instance is associated with.
+                The ID of the infrastructure port profile this instance is associated with.
 
                 
                 This attribute is named `infrastructureProfileID` in VSD API.
@@ -370,7 +381,7 @@ class NURedundantPort(NURESTObject):
         """ Set infrastructure_profile_id value.
 
             Notes:
-                The ID of the infrastructure profile this instance is associated with.
+                The ID of the infrastructure port profile this instance is associated with.
 
                 
                 This attribute is named `infrastructureProfileID` in VSD API.
@@ -411,7 +422,7 @@ class NURedundantPort(NURESTObject):
         """ Get port_peer1_id value.
 
             Notes:
-                The master gateway peer port id.
+                Port ID of the port acting as master component of the redundant port instance.
 
                 
                 This attribute is named `portPeer1ID` in VSD API.
@@ -424,7 +435,7 @@ class NURedundantPort(NURESTObject):
         """ Set port_peer1_id value.
 
             Notes:
-                The master gateway peer port id.
+                Port ID of the port acting as master component of the redundant port instance.
 
                 
                 This attribute is named `portPeer1ID` in VSD API.
@@ -438,7 +449,7 @@ class NURedundantPort(NURESTObject):
         """ Get port_peer2_id value.
 
             Notes:
-                The slave gateway peer port id.
+                Port ID of the port acting as slave component of the redundant port instance.
 
                 
                 This attribute is named `portPeer2ID` in VSD API.
@@ -451,7 +462,7 @@ class NURedundantPort(NURESTObject):
         """ Set port_peer2_id value.
 
             Notes:
-                The slave gateway peer port id.
+                Port ID of the port acting as slave component of the redundant port instance.
 
                 
                 This attribute is named `portPeer2ID` in VSD API.
@@ -465,7 +476,7 @@ class NURedundantPort(NURESTObject):
         """ Get port_type value.
 
             Notes:
-                Type of the Port.
+                Type of the Redundant Port.
 
                 
                 This attribute is named `portType` in VSD API.
@@ -478,7 +489,7 @@ class NURedundantPort(NURESTObject):
         """ Set port_type value.
 
             Notes:
-                Type of the Port.
+                Type of the Redundant Port.
 
                 
                 This attribute is named `portType` in VSD API.
@@ -542,7 +553,7 @@ class NURedundantPort(NURESTObject):
         """ Get use_user_mnemonic value.
 
             Notes:
-                determines whether to use user mnemonic of the Port
+                Determines whether to use user mnemonic of the Port
 
                 
                 This attribute is named `useUserMnemonic` in VSD API.
@@ -555,7 +566,7 @@ class NURedundantPort(NURESTObject):
         """ Set use_user_mnemonic value.
 
             Notes:
-                determines whether to use user mnemonic of the Port
+                Determines whether to use user mnemonic of the Port
 
                 
                 This attribute is named `useUserMnemonic` in VSD API.
@@ -569,7 +580,7 @@ class NURedundantPort(NURESTObject):
         """ Get user_mnemonic value.
 
             Notes:
-                user mnemonic of the Port
+                User mnemonic of the Redundant Port.
 
                 
                 This attribute is named `userMnemonic` in VSD API.
@@ -582,7 +593,7 @@ class NURedundantPort(NURESTObject):
         """ Set user_mnemonic value.
 
             Notes:
-                user mnemonic of the Port
+                User mnemonic of the Redundant Port.
 
                 
                 This attribute is named `userMnemonic` in VSD API.
@@ -596,7 +607,7 @@ class NURedundantPort(NURESTObject):
         """ Get associated_egress_qos_policy_id value.
 
             Notes:
-                ID of the Egress QOS Policy associated with this Vlan.
+                ID of the Egress QoS Policy associated with this Redundant Port.
 
                 
                 This attribute is named `associatedEgressQOSPolicyID` in VSD API.
@@ -609,7 +620,7 @@ class NURedundantPort(NURESTObject):
         """ Set associated_egress_qos_policy_id value.
 
             Notes:
-                ID of the Egress QOS Policy associated with this Vlan.
+                ID of the Egress QoS Policy associated with this Redundant Port.
 
                 
                 This attribute is named `associatedEgressQOSPolicyID` in VSD API.
@@ -623,7 +634,7 @@ class NURedundantPort(NURESTObject):
         """ Get status value.
 
             Notes:
-                Status of the port.
+                Status of the redundant port.
 
                 
         """
@@ -634,7 +645,7 @@ class NURedundantPort(NURESTObject):
         """ Set status value.
 
             Notes:
-                Status of the port.
+                Status of the redundant port.
 
                 
         """
