@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUAddressRangesFetcher
 
 
@@ -72,6 +73,8 @@ class NUSubnetTemplate(NURESTObject):
     
     CONST_ENCRYPTION_DISABLED = "DISABLED"
     
+    CONST_USE_GLOBAL_MAC_ENTERPRISE_DEFAULT = "ENTERPRISE_DEFAULT"
+    
     CONST_DPI_ENABLED = "ENABLED"
     
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
@@ -111,8 +114,8 @@ class NUSubnetTemplate(NURESTObject):
         
         self._dpi = None
         self._ip_type = None
+        self._ipv6_address = None
         self._ipv6_gateway = None
-        self._ipv6address = None
         self._name = None
         self._last_updated_by = None
         self._gateway = None
@@ -127,11 +130,12 @@ class NUSubnetTemplate(NURESTObject):
         self._associated_multicast_channel_map_id = None
         self._multicast = None
         self._external_id = None
+        self._dynamic_ipv6_address = None
         
         self.expose_attribute(local_name="dpi", remote_name="DPI", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="ip_type", remote_name="IPType", attribute_type=str, is_required=False, is_unique=False, choices=[u'DUALSTACK', u'IPV4'])
+        self.expose_attribute(local_name="ipv6_address", remote_name="IPv6Address", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="ipv6_gateway", remote_name="IPv6Gateway", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="ipv6address", remote_name="IPv6address", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway", remote_name="gateway", attribute_type=str, is_required=False, is_unique=False)
@@ -142,10 +146,11 @@ class NUSubnetTemplate(NURESTObject):
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="split_subnet", remote_name="splitSubnet", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="proxy_arp", remote_name="proxyARP", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="use_global_mac", remote_name="useGlobalMAC", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
+        self.expose_attribute(local_name="use_global_mac", remote_name="useGlobalMAC", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'ENTERPRISE_DEFAULT'])
         self.expose_attribute(local_name="associated_multicast_channel_map_id", remote_name="associatedMulticastChannelMapID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="multicast", remote_name="multicast", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
+        self.expose_attribute(local_name="dynamic_ipv6_address", remote_name="dynamicIpv6Address", attribute_type=bool, is_required=False, is_unique=False)
         
 
         # Fetchers
@@ -227,6 +232,33 @@ class NUSubnetTemplate(NURESTObject):
         self._ip_type = value
 
     
+    @property
+    def ipv6_address(self):
+        """ Get ipv6_address value.
+
+            Notes:
+                IPv6 range of the subnet. In case of zone, this is an optional field for and allows users to allocate an IP address range to a zone. The VSD will auto-assign IP addresses to subnets from this range if a specific IP address is not defined for the subnet
+
+                
+                This attribute is named `IPv6Address` in VSD API.
+                
+        """
+        return self._ipv6_address
+
+    @ipv6_address.setter
+    def ipv6_address(self, value):
+        """ Set ipv6_address value.
+
+            Notes:
+                IPv6 range of the subnet. In case of zone, this is an optional field for and allows users to allocate an IP address range to a zone. The VSD will auto-assign IP addresses to subnets from this range if a specific IP address is not defined for the subnet
+
+                
+                This attribute is named `IPv6Address` in VSD API.
+                
+        """
+        self._ipv6_address = value
+
+    
     @property
     def ipv6_gateway(self):
         """ Get ipv6_gateway value.
@@ -254,33 +286,6 @@ class NUSubnetTemplate(NURESTObject):
         self._ipv6_gateway = value
 
     
-    @property
-    def ipv6address(self):
-        """ Get ipv6address value.
-
-            Notes:
-                IPv6 address of the subnet defined. In case of zone, this is an optional field for and allows users to allocate an IP address range to a zone. The VSD will auto-assign IP addresses to subnets from this range if a specific IP address is not defined for the subnet
-
-                
-                This attribute is named `IPv6address` in VSD API.
-                
-        """
-        return self._ipv6address
-
-    @ipv6address.setter
-    def ipv6address(self, value):
-        """ Set ipv6address value.
-
-            Notes:
-                IPv6 address of the subnet defined. In case of zone, this is an optional field for and allows users to allocate an IP address range to a zone. The VSD will auto-assign IP addresses to subnets from this range if a specific IP address is not defined for the subnet
-
-                
-                This attribute is named `IPv6address` in VSD API.
-                
-        """
-        self._ipv6address = value
-
-    
     @property
     def name(self):
         """ Get name value.
@@ -478,7 +483,7 @@ class NUSubnetTemplate(NURESTObject):
         """ Get split_subnet value.
 
             Notes:
-                Need to add correct description
+                Block subnet routes
 
                 
                 This attribute is named `splitSubnet` in VSD API.
@@ -491,7 +496,7 @@ class NUSubnetTemplate(NURESTObject):
         """ Set split_subnet value.
 
             Notes:
-                Need to add correct description
+                Block subnet routes
 
                 
                 This attribute is named `splitSubnet` in VSD API.
@@ -505,7 +510,7 @@ class NUSubnetTemplate(NURESTObject):
         """ Get proxy_arp value.
 
             Notes:
-                 when set VRS will act as  ARP Proxy
+                 When set, VRS will act as  ARP Proxy
 
                 
                 This attribute is named `proxyARP` in VSD API.
@@ -518,7 +523,7 @@ class NUSubnetTemplate(NURESTObject):
         """ Set proxy_arp value.
 
             Notes:
-                 when set VRS will act as  ARP Proxy
+                 When set, VRS will act as  ARP Proxy
 
                 
                 This attribute is named `proxyARP` in VSD API.
@@ -631,6 +636,33 @@ class NUSubnetTemplate(NURESTObject):
         self._external_id = value
 
     
+    @property
+    def dynamic_ipv6_address(self):
+        """ Get dynamic_ipv6_address value.
+
+            Notes:
+                Turn on or off dynamic allocation of IPV6 address
+
+                
+                This attribute is named `dynamicIpv6Address` in VSD API.
+                
+        """
+        return self._dynamic_ipv6_address
+
+    @dynamic_ipv6_address.setter
+    def dynamic_ipv6_address(self, value):
+        """ Set dynamic_ipv6_address value.
+
+            Notes:
+                Turn on or off dynamic allocation of IPV6 address
+
+                
+                This attribute is named `dynamicIpv6Address` in VSD API.
+                
+        """
+        self._dynamic_ipv6_address = value
+
+    
 
     
     ## Custom methods
